==> qtjambi-multimedia-debuginfo-linux-x64-5.15.18.jar: sources/QtJambiMultimedia/QRadioData_shell.h <==
#ifndef QRADIODATA_SHELL_H
#define QRADIODATA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qradiodata.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaobject.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtJambi/RegistryAPI>


class QRadioData_shell : public QRadioData, public QtJambiShellInterface
{
public:
    QRadioData_shell(QMediaObject* mediaObject0, QObject* parent1 = nullptr);
    ~QRadioData_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QMediaObject* mediaObject() const override;
    bool setMediaObject(QMediaObject* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRadioData_access : public QRadioData
{
    jobject __qt_mediaObject(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setMediaObject_QMediaObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QRADIODATA_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-5.15.20.jar: sources/QtJambiMultimedia/QRadioData_shell.h <==
#ifndef QRADIODATA_SHELL_H
#define QRADIODATA_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qradiodata.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtMultimedia/qmediaobject.h>
#include <QtMultimedia/qmultimedia.h>
#include <QtJambi/RegistryAPI>


class QRadioData_shell : public QRadioData, public QtJambiShellInterface
{
public:
    QRadioData_shell(QMediaObject* mediaObject0, QObject* parent1 = nullptr);
    ~QRadioData_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    QMediaObject* mediaObject() const override;
    bool setMediaObject(QMediaObject* arg__1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QRadioData_access : public QRadioData
{
    jobject __qt_mediaObject_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_setMediaObject_QMediaObject_ptr(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID arg__1);
};

#endif // QRADIODATA_SHELL_H
